@@ -2080,8 +2080,7 @@ void DrawBlock(display, window, row, col, blockType)
 		case KILL_BLK:		/* Special block - blow it up */
 			PlaySoundForBlock(blockP->blockType);
 
-			if (blockP->blockType != BLACK_BLK)
-				SetBlockUpForExplosion(row, col, frame);
+			SetBlockUpForExplosion(row, col, frame);
 			break;
 
 		default:			/* Your average block - draw it */
@@ -2586,6 +2585,7 @@ void SkipToNextLevel(display, window)
 	 */
 
 	for (r = 0; r < MAX_ROW; r++)
+	{
 		for (c = 0; c < MAX_COL; c++)
 		{
 			/* Pointer to the block we want */
@@ -2621,6 +2621,13 @@ void SkipToNextLevel(display, window)
 				}
 			}
 		}
+	}
+
+   	/* Special effect where screen shakes
+     * during explosion
+     */
+    SetSfxEndFrame(frame + 140);
+    changeSfxMode(SFX_SHAKE);
 }
 
 #if NeedFunctionPrototypes
