@@ -272,6 +272,7 @@ void SetupBonusScreen(display, window)
 	/* Remove the window to show bonus stuff */
 	while (WindowFadeEffect(display, playWindow, PLAY_WIDTH, PLAY_HEIGHT));
 	XUnmapWindow(display, playWindow);
+	XFlush(display);
 }
 
 #if NeedFunctionPrototypes
@@ -307,9 +308,9 @@ void DrawTitleText(display, window)
 		DEBUG("Saving activated.")
 	}
 
-	BonusState = BONUS_SCORE;
+	XFlush(display);
 
-	/* Just in case it has changed */
+	SetBonusWait(BONUS_SCORE, frame + 5);
 	SetGameSpeed(SLOW_SPEED);
 
 	DEBUG("set bonus mode to BONUS_SCORE.")
@@ -336,6 +337,7 @@ static void DoScore(display, window)
 	ypos += (35 + GAP);
 	SetBonusWait(BONUS_BONUS, frame + LINE_DELAY);
 	SetGameSpeed(SLOW_SPEED);
+	DEBUG("set bonus mode to BONUS_BONUS.")
 }
 
 #if NeedFunctionPrototypes
@@ -444,6 +446,7 @@ static void DoBonuses(display, window)
 	{
 		/* Set up bonus state for next sequence */
 		SetBonusWait(BONUS_LEVEL, frame + LINE_DELAY);
+		DEBUG("set bonus mode to BONUS_LEVEL.")
 
 		/* Make sure bonus is reset */
 		ResetNumberBonus();
@@ -753,38 +756,47 @@ void DoBonus(display, window)
 	switch (BonusState)
 	{
 		case BONUS_TEXT:
+			DEBUG("BONUS: DrawTitleText()")
 			DrawTitleText(display, window);
 			break;
 
 		case BONUS_SCORE:
+			DEBUG("BONUS: DoScore()")
 			DoScore(display, window);
 			break;
 
 		case BONUS_BONUS:
+			DEBUG("BONUS: DoBonuses()")
 			DoBonuses(display, window);
 			break;
 
 		case BONUS_LEVEL:
+			DEBUG("BONUS: DoLevel()")
 			DoLevel(display, window);
 			break;
 
 		case BONUS_BULLET:
+			DEBUG("BONUS: DoBullets()")
 			DoBullets(display, window);
 			break;
 
 		case BONUS_TIME:
+			DEBUG("BONUS: DoTimeBonus()")
 			DoTimeBonus(display, window);
 			break;
 
 		case BONUS_HSCORE:
+			DEBUG("BONUS: DoHighScore()")
 			DoHighScore(display, window);
 			break;
 
 		case BONUS_END_TEXT:
+			DEBUG("BONUS: DoEndText()")
 			DoEndText(display, window);
 			break;
 
 		case BONUS_FINISH:
+			DEBUG("BONUS: DoFinish()")
 			DoFinish(display, window);
 			break;
 
