@@ -51,6 +51,7 @@
 #include <stdio.h>
 #include <math.h>
 #include <assert.h>
+#include <X11/Xos.h>
 
 #include "bitmaps/guns/bullet.xpm"
 #include "bitmaps/guns/tink.xpm"
@@ -347,18 +348,22 @@ static void UpdateBullet(display, window)
 			/* Pointer to the correct block we need - speed things up */
 			blockP = &blocks[row][col];
 
-			if (CheckEyeDudeBulletCollision(display, window, 
-				bullets[i].xpos, bullets[i].ypos) == True)
+			if (getEyeDudeMode() == EYEDUDE_WALK)
 			{
-				/* Clear the bullet from the screen */
-				EraseTheBullet(display, window, 
-					bullets[i].xpos, bullets[i].oldypos);
+				/* See if the bullet has hit the active eyedude */
+				if (CheckEyeDudeBulletCollision(display, window, 
+					bullets[i].xpos, bullets[i].ypos) == True)
+				{
+					/* Clear the bullet from the screen */
+					EraseTheBullet(display, window, 
+						bullets[i].xpos, bullets[i].oldypos);
 
-				/* Ok so the eyedude has been hit - arrggh */
-				ChangeEyeDudeMode(EYEDUDE_DIE);
+					/* Ok so the eyedude has been hit - arrggh */
+					ChangeEyeDudeMode(EYEDUDE_DIE);
 
-				/* Free the bullet up for another */
-				ClearBullet(i);
+					/* Free the bullet up for another */
+					ClearBullet(i);
+				}
 			}
 
 			/* Check if the bullet has hit a brick or something */
