@@ -1490,9 +1490,9 @@ static void handleEventLoop(display)
 }
 
 #if NeedFunctionPrototypes
-void main(int argc, char **argv)
+int main(int argc, char **argv)
 #else
-void main(argc, argv)
+int main(argc, argv)
 	int argc;
 	char **argv;
 #endif
